package beautiful02.ex2;

import junit.framework.TestCase;

import org.seasar.extension.dataset.DataTable;
import org.seasar.extension.dataset.impl.XlsReader;

import beautiful02.dao.mock.MockUserDao;

public class UserImportLogicImplTest extends TestCase {

	UserImportLogicImpl userImportLogic;
	
	@Override
	protected void setUp() throws Exception {
		userImportLogic = new UserImportLogicImpl();
		userImportLogic.setUserDao(new MockUserDao());
	}
	
	public void testValidateTableAndImportTable() throws Exception {
		XlsReader reader = new XlsReader(getClass().getResourceAsStream("/beautiful02/users.xls"));
		DataTable table = reader.read().getTable("[Uꗗ");
		ImportResult result = userImportLogic.validateTable(table);
		assertEquals("G[", 0, result.getErrors().size());
		result = userImportLogic.importTable(table);
		assertEquals("G[", 0, result.getErrors().size());
	}

	public void testValidateTableAndImportTableHasErrors() throws Exception {
		XlsReader reader = new XlsReader(getClass().getResourceAsStream("/beautiful02/users_hasErrors.xls"));
		DataTable table = reader.read().getTable("[Uꗗ");
		ImportResult result = userImportLogic.validateTable(table);
		assertEquals("G[", 2, result.getErrors().size());
		assertEquals("sԍ", new Integer(3), result.getErrors().get(0).getLineNumber());
		assertEquals("G[bZ[W", "͕K{łB", result.getErrors().get(0).getMessage());
		assertEquals("sԍ", new Integer(7), result.getErrors().get(1).getLineNumber());
		assertEquals("G[bZ[W", "ʂ[0, 1]݂̂œ͂ĂB", result.getErrors().get(1).getMessage());

		result = userImportLogic.importTable(table);
		assertEquals("G[", 2, result.getErrors().size());
		assertEquals("sԍ", new Integer(3), result.getErrors().get(0).getLineNumber());
		assertEquals("G[bZ[W", "͕K{łB", result.getErrors().get(0).getMessage());
		assertEquals("sԍ", new Integer(7), result.getErrors().get(1).getLineNumber());
		assertEquals("G[bZ[W", "ʂ[0, 1]݂̂œ͂ĂB", result.getErrors().get(1).getMessage());
	}
}
